@@ -69,7 +69,7 @@ class Exceptions:
 
 class QLDBClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/qldb.html#QLDB.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/qldb.html#QLDB.Client)
     [Show boto3-stubs documentation](./client.md)
     """
 
@@ -78,16 +78,16 @@ class QLDBClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/qldb.html#QLDB.Client.can_paginate)
-        [Show boto3-stubs documentation](./client.md#can-paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/qldb.html#QLDB.Client.can_paginate)
+        [Show boto3-stubs documentation](./client.md#can_paginate)
         """
 
     def cancel_journal_kinesis_stream(
         self, LedgerName: str, StreamId: str
     ) -> CancelJournalKinesisStreamResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/qldb.html#QLDB.Client.cancel_journal_kinesis_stream)
-        [Show boto3-stubs documentation](./client.md#cancel-journal-kinesis-stream)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/qldb.html#QLDB.Client.cancel_journal_kinesis_stream)
+        [Show boto3-stubs documentation](./client.md#cancel_journal_kinesis_stream)
         """
 
     def create_ledger(
@@ -98,36 +98,36 @@ class QLDBClient:
         DeletionProtection: bool = None,
     ) -> CreateLedgerResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/qldb.html#QLDB.Client.create_ledger)
-        [Show boto3-stubs documentation](./client.md#create-ledger)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/qldb.html#QLDB.Client.create_ledger)
+        [Show boto3-stubs documentation](./client.md#create_ledger)
         """
 
     def delete_ledger(self, Name: str) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/qldb.html#QLDB.Client.delete_ledger)
-        [Show boto3-stubs documentation](./client.md#delete-ledger)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/qldb.html#QLDB.Client.delete_ledger)
+        [Show boto3-stubs documentation](./client.md#delete_ledger)
         """
 
     def describe_journal_kinesis_stream(
         self, LedgerName: str, StreamId: str
     ) -> DescribeJournalKinesisStreamResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/qldb.html#QLDB.Client.describe_journal_kinesis_stream)
-        [Show boto3-stubs documentation](./client.md#describe-journal-kinesis-stream)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/qldb.html#QLDB.Client.describe_journal_kinesis_stream)
+        [Show boto3-stubs documentation](./client.md#describe_journal_kinesis_stream)
         """
 
     def describe_journal_s3_export(
         self, Name: str, ExportId: str
     ) -> DescribeJournalS3ExportResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/qldb.html#QLDB.Client.describe_journal_s3_export)
-        [Show boto3-stubs documentation](./client.md#describe-journal-s3-export)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/qldb.html#QLDB.Client.describe_journal_s3_export)
+        [Show boto3-stubs documentation](./client.md#describe_journal_s3_export)
         """
 
     def describe_ledger(self, Name: str) -> DescribeLedgerResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/qldb.html#QLDB.Client.describe_ledger)
-        [Show boto3-stubs documentation](./client.md#describe-ledger)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/qldb.html#QLDB.Client.describe_ledger)
+        [Show boto3-stubs documentation](./client.md#describe_ledger)
         """
 
     def export_journal_to_s3(
@@ -139,8 +139,8 @@ class QLDBClient:
         RoleArn: str,
     ) -> ExportJournalToS3ResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/qldb.html#QLDB.Client.export_journal_to_s3)
-        [Show boto3-stubs documentation](./client.md#export-journal-to-s3)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/qldb.html#QLDB.Client.export_journal_to_s3)
+        [Show boto3-stubs documentation](./client.md#export_journal_to_s3)
         """
 
     def generate_presigned_url(
@@ -151,8 +151,8 @@ class QLDBClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/qldb.html#QLDB.Client.generate_presigned_url)
-        [Show boto3-stubs documentation](./client.md#generate-presigned-url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/qldb.html#QLDB.Client.generate_presigned_url)
+        [Show boto3-stubs documentation](./client.md#generate_presigned_url)
         """
 
     def get_block(
@@ -162,14 +162,14 @@ class QLDBClient:
         DigestTipAddress: "ValueHolderTypeDef" = None,
     ) -> GetBlockResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/qldb.html#QLDB.Client.get_block)
-        [Show boto3-stubs documentation](./client.md#get-block)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/qldb.html#QLDB.Client.get_block)
+        [Show boto3-stubs documentation](./client.md#get_block)
         """
 
     def get_digest(self, Name: str) -> GetDigestResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/qldb.html#QLDB.Client.get_digest)
-        [Show boto3-stubs documentation](./client.md#get-digest)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/qldb.html#QLDB.Client.get_digest)
+        [Show boto3-stubs documentation](./client.md#get_digest)
         """
 
     def get_revision(
@@ -180,46 +180,46 @@ class QLDBClient:
         DigestTipAddress: "ValueHolderTypeDef" = None,
     ) -> GetRevisionResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/qldb.html#QLDB.Client.get_revision)
-        [Show boto3-stubs documentation](./client.md#get-revision)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/qldb.html#QLDB.Client.get_revision)
+        [Show boto3-stubs documentation](./client.md#get_revision)
         """
 
     def list_journal_kinesis_streams_for_ledger(
         self, LedgerName: str, MaxResults: int = None, NextToken: str = None
     ) -> ListJournalKinesisStreamsForLedgerResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/qldb.html#QLDB.Client.list_journal_kinesis_streams_for_ledger)
-        [Show boto3-stubs documentation](./client.md#list-journal-kinesis-streams-for-ledger)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/qldb.html#QLDB.Client.list_journal_kinesis_streams_for_ledger)
+        [Show boto3-stubs documentation](./client.md#list_journal_kinesis_streams_for_ledger)
         """
 
     def list_journal_s3_exports(
         self, MaxResults: int = None, NextToken: str = None
     ) -> ListJournalS3ExportsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/qldb.html#QLDB.Client.list_journal_s3_exports)
-        [Show boto3-stubs documentation](./client.md#list-journal-s3-exports)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/qldb.html#QLDB.Client.list_journal_s3_exports)
+        [Show boto3-stubs documentation](./client.md#list_journal_s3_exports)
         """
 
     def list_journal_s3_exports_for_ledger(
         self, Name: str, MaxResults: int = None, NextToken: str = None
     ) -> ListJournalS3ExportsForLedgerResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/qldb.html#QLDB.Client.list_journal_s3_exports_for_ledger)
-        [Show boto3-stubs documentation](./client.md#list-journal-s3-exports-for-ledger)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/qldb.html#QLDB.Client.list_journal_s3_exports_for_ledger)
+        [Show boto3-stubs documentation](./client.md#list_journal_s3_exports_for_ledger)
         """
 
     def list_ledgers(
         self, MaxResults: int = None, NextToken: str = None
     ) -> ListLedgersResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/qldb.html#QLDB.Client.list_ledgers)
-        [Show boto3-stubs documentation](./client.md#list-ledgers)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/qldb.html#QLDB.Client.list_ledgers)
+        [Show boto3-stubs documentation](./client.md#list_ledgers)
         """
 
     def list_tags_for_resource(self, ResourceArn: str) -> ListTagsForResourceResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/qldb.html#QLDB.Client.list_tags_for_resource)
-        [Show boto3-stubs documentation](./client.md#list-tags-for-resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/qldb.html#QLDB.Client.list_tags_for_resource)
+        [Show boto3-stubs documentation](./client.md#list_tags_for_resource)
         """
 
     def stream_journal_to_kinesis(
@@ -233,26 +233,26 @@ class QLDBClient:
         ExclusiveEndTime: datetime = None,
     ) -> StreamJournalToKinesisResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/qldb.html#QLDB.Client.stream_journal_to_kinesis)
-        [Show boto3-stubs documentation](./client.md#stream-journal-to-kinesis)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/qldb.html#QLDB.Client.stream_journal_to_kinesis)
+        [Show boto3-stubs documentation](./client.md#stream_journal_to_kinesis)
         """
 
     def tag_resource(self, ResourceArn: str, Tags: Dict[str, str]) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/qldb.html#QLDB.Client.tag_resource)
-        [Show boto3-stubs documentation](./client.md#tag-resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/qldb.html#QLDB.Client.tag_resource)
+        [Show boto3-stubs documentation](./client.md#tag_resource)
         """
 
     def untag_resource(self, ResourceArn: str, TagKeys: List[str]) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/qldb.html#QLDB.Client.untag_resource)
-        [Show boto3-stubs documentation](./client.md#untag-resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/qldb.html#QLDB.Client.untag_resource)
+        [Show boto3-stubs documentation](./client.md#untag_resource)
         """
 
     def update_ledger(
         self, Name: str, DeletionProtection: bool = None
     ) -> UpdateLedgerResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/qldb.html#QLDB.Client.update_ledger)
-        [Show boto3-stubs documentation](./client.md#update-ledger)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/qldb.html#QLDB.Client.update_ledger)
+        [Show boto3-stubs documentation](./client.md#update_ledger)
         """
